Changes for bmi-topography
==========================

0.3 (unreleased)
----------------

- Nothing changed yet.


0.2 (2021-02-24)
----------------

* Implement BMI for Topography class from template generated by `bmipy-render`
* Include sample config file and Jupyter Notebook to demo BMI
* Add CI with GitHub Actions


0.1.1 (2021-02-22)
------------------

* Add Makefile rule to test upload to TestPyPI
* Test upload to TestPyPI


0.1 (2021-02-22)
----------------

* Create base library that calls OpenTopography API
* Create CLI for library
* Write tests for library and CLI
* Include demo Jupyter Notebook for library
